function ret = gui_active(optional_input)
%
% gui_active - used to implement an abort function in a GUI
%
% initially : gui_active(1)
%
% in the aplication, occaisionally 
%  EITHER  1) if (~gui_active) then ... do abort action
%  OR      2) polling gui_active(-1) will cause an error with the value 'abort_requested'
%             that can be caught with a "try-catch" block
%
% to initiate the abort (for both cases) call:  gui_active(0)
%

% the call to drawnow enable other controls to "patch-in" before the
% rest of this code execute and possibly change the "is_active" state

persistent    is_active;    % Define persistent variable = is_active
if (nargin > 0)             % nargin is 'Number of function input arguments'
    if (optional_input == -1) 
        drawnow;            % DRAWNOW "flushes the event queue" and forces MATLAB to update the screen
        if (~is_active)     % if the persisten variable is not as defined, show error
            error('abort_requested');   % Show message error
        end
    else
        prev_is_active  = is_active;      % set is_active to prev_is_active value
        is_active       = optional_input;   
        if ((prev_is_active > 0) & (is_active == 0))  %This will abort the progress bar
            disp('operation aborted');
        end
    end
else
    drawnow;
end

ret = is_active;       % ret will be using later

